@@ -32,7 +32,7 @@ shine.coverages <- function(x, ...) {
     ),
     shiny::column(8,
       shiny::tabsetPanel(
-        shiny::tabPanel("Files", DT::dataTableOutput(outputId="file_table")),
+        shiny::tabPanel("Files", DT::dataTableOutput(outputId = "file_table")),
         shiny::tabPanel("Source", addHighlight(shiny::tableOutput("source_table")))
         )
       ),
@@ -43,6 +43,7 @@ shine.coverages <- function(x, ...) {
       data[[input$type]]$file_stats,
       escape = FALSE,
       options = list(searching = FALSE, dom = "t", paging = FALSE),
+      rownames = FALSE,
       callback = DT::JS("table.on('click.dt', 'a', function() {
         Shiny.onInputChange('filename', $(this).text());
         $('ul.nav a[data-value=Source]').tab('show');
@@ -71,7 +72,7 @@ shine.coverage <- function(x, ...) {
     shiny::includeCSS(system.file("www/shiny.css", package = "covr")),
     shiny::column(8, offset = 2,
       shiny::tabsetPanel(
-        shiny::tabPanel("Files", DT::dataTableOutput(outputId="file_table")),
+        shiny::tabPanel("Files", DT::dataTableOutput(outputId = "file_table")),
         shiny::tabPanel("Source", addHighlight(shiny::tableOutput("source_table")))
         )
       ),
@@ -82,6 +83,7 @@ shine.coverage <- function(x, ...) {
       data$file_stats,
       escape = FALSE,
       options = list(searching = FALSE, dom = "t", paging = FALSE),
+      rownames = FALSE,
       callback = DT::JS("table.on('click.dt', 'a', function() {
         Shiny.onInputChange('filename', $(this).text());
         $('ul.nav a[data-value=Source]').tab('show');
@@ -114,7 +116,12 @@ to_shiny_data <- function(x) {
         coverage = values,
         stringsAsFactors = FALSE)
     })
-  names(res$full) <- display_name(coverages)
+  nms <- names(coverages)
+
+  # set a temp name if it doesn't exist
+  nms[nms == ""] <- "<text>"
+
+  names(res$full) <- nms
 
   res$file_stats <- compute_file_stats(res$full)
 
@@ -191,20 +198,20 @@ renderSourceTable <- function(expr, env = parent.frame()) {
                 coverage <- data[row_num, "coverage"]
 
                 cov_type <- NULL
-                if(coverage == 0) {
+                if (coverage == 0) {
                   cov_value <- "!"
                   cov_type <- "missed"
-                } else if(coverage > 0) {
+                } else if (coverage > 0) {
                   cov_value <- shiny::HTML(paste0(data[row_num, "coverage"], "<em>x</em>", collapse = ""))
                   cov_type <- "covered"
                 } else {
                   cov_type <- "never"
                   cov_value <- ""
                 }
-                shiny::tags$tr(class=cov_type,
-                  shiny::tags$td(class="num", data[row_num, "line"]),
-                  shiny::tags$td(class="col-sm-12", shiny::pre(class="language-r", data[row_num, "source"])),
-                  shiny::tags$td(class="coverage", cov_value)
+                shiny::tags$tr(class = cov_type,
+                  shiny::tags$td(class = "num", data[row_num, "line"]),
+                  shiny::tags$td(class = "col-sm-12", shiny::pre(class = "language-r", data[row_num, "source"])),
+                  shiny::tags$td(class = "coverage", cov_value)
                   )
               })
             )
