@@ -16,11 +16,11 @@ trace_calls <- function (x, parent_functions = NULL, parent_ref = NULL) {
   }
 
   if (is.atomic(x) || is.name(x)) {
-    if (length(x) == 0 || is.null(parent_ref)) {
+    if (is.null(parent_ref)) {
       x
     }
     else {
-      if ((!is.symbol(x) && is.na(x)) || as.character(x) == "{") {
+      if (is_na(x) || is_brace(x)) {
         x
       } else {
         key <- new_counter(parent_ref, parent_functions) # nolint
@@ -29,11 +29,11 @@ trace_calls <- function (x, parent_functions = NULL, parent_ref = NULL) {
     }
   }
   else if (is.call(x)) {
-    if ((identical(x[[1]], as.name("<-")) || identical(x[[1]], as.name("="))) &&
+    if ((identical(x[[1]], as.name("<-")) || identical(x[[1]], as.name("="))) && # nolint
         (is.call(x[[3]]) && identical(x[[3]][[1]], as.name("function")))) {
       parent_functions <- c(parent_functions, as.character(x[[2]]))
     }
-    src_ref <- attr(x, "srcref")
+    src_ref <- attr(x, "srcref") %||% impute_srcref(x, parent_ref)
     if (!is.null(src_ref)) {
       as.call(Map(trace_calls, x, src_ref, MoreArgs = list(parent_functions = parent_functions)))
     } else if (!is.null(parent_ref)) {
@@ -46,7 +46,7 @@ trace_calls <- function (x, parent_functions = NULL, parent_ref = NULL) {
   else if (is.function(x)) {
     fun_body <- body(x)
 
-    if(!is.null(fun_body) && !is.null(attr(x, "srcref")) &&
+    if (!is.null(attr(x, "srcref")) &&
        (is.symbol(fun_body) || !identical(fun_body[[1]], as.name("{")))) {
       src_ref <- attr(x, "srcref")
       key <- new_counter(src_ref, parent_functions)
@@ -101,15 +101,14 @@ count <- function(key) {
 #' clear all previous counters
 #'
 clear_counters <- function() {
-  rm(envir = .counters, list=ls(envir = .counters))
+  rm(envir = .counters, list = ls(envir = .counters))
 }
 
 #' Generate a key for a  call
 #'
 #' @param x the srcref of the call to create a key for
 key <- function(x) {
-  src_file <- attr(x, "srcfile")
-  paste(collapse = ":", c(address(src_file), x))
+  paste(collapse = ":", c(utils::getSrcFilename(x), x))
 }
 
 f1 <- function() {
